@@ -2,11 +2,12 @@ import abc
 import enum
 import json
 import typing
-import numpy as np
 import pandas as pd
+from pandas.api.types import is_numeric_dtype
 
 from ipyvizzu.json import RawJavaScript, RawJavaScriptEncoder
 from ipyvizzu.template import DisplayTemplate
+from ipyvizzu.schema import DataSchema
 
 
 class Animation:
@@ -29,7 +30,6 @@ class InferType(enum.Enum):
 
     DIMENSION = "dimension"
     MEASURE = "measure"
-    AUTO = None
 
 
 class Data(dict, Animation):
@@ -74,30 +74,26 @@ class Data(dict, Animation):
     def add_data_frame(
         self,
         data_frame,
-        infer_types=None,
         default_measure_value=0,
         default_dimension_value="",
     ):
         if not isinstance(data_frame, type(None)):
-            if infer_types is None:
-                infer_types = {}
             if isinstance(data_frame, pd.core.series.Series):
                 data_frame = pd.DataFrame(data_frame)
+            if not isinstance(data_frame, pd.DataFrame):
+                raise TypeError(
+                    "data_frame must be instance of pandas.DataFrame or pandas.Series"
+                )
             for name in data_frame.columns:
-                infer_type = InferType(infer_types.get(name, InferType.AUTO))
-                if infer_type == InferType.AUTO:
-                    if isinstance(data_frame[name].values[0], (np.float64, np.int64)):
-                        infer_type = InferType.MEASURE
-                    else:
-                        infer_type = InferType.DIMENSION
-
                 values = []
-                if infer_type == InferType.MEASURE:
+                if is_numeric_dtype(data_frame[name].dtype):
+                    infer_type = InferType.MEASURE
                     values = [
                         float(i)
                         for i in data_frame[name].fillna(default_measure_value).values
                     ]
                 else:
+                    infer_type = InferType.DIMENSION
                     values = [
                         str(i)
                         for i in data_frame[name].fillna(default_dimension_value).values
@@ -109,6 +105,24 @@ class Data(dict, Animation):
                     type=infer_type.value,
                 )
 
+    def add_data_frame_index(
+        self,
+        data_frame,
+        name: typing.Optional[str],
+    ):
+        if data_frame is not None:
+            if isinstance(data_frame, pd.core.series.Series):
+                data_frame = pd.DataFrame(data_frame)
+            if not isinstance(data_frame, pd.DataFrame):
+                raise TypeError(
+                    "data_frame must be instance of pandas.DataFrame or pandas.Series"
+                )
+            self.add_series(
+                str(name),
+                [str(i) for i in data_frame.index],
+                type=InferType.DIMENSION.value,
+            )
+
     def _add_named_value(self, dest, name, values=None, **kwargs):
         value = {"name": name, **kwargs}
 
@@ -121,6 +135,7 @@ class Data(dict, Animation):
         self.setdefault(dest, []).append(value)
 
     def build(self):
+        DataSchema.validate(self)
         return {"data": self}
 
 
