@@ -11,9 +11,9 @@ class DisplayTarget(str, enum.Enum):
 
 class DisplayTemplate:
 
-    INIT = """
-        {ipyvizzu_js}
-        window.ipyvizzu = new window.IpyVizzu(element, "{chart_id}", "{vizzu}", "{div_width}", "{div_height}");"""  # pylint: disable=line-too-long
+    IPYVIZZUJS = "{ipyvizzujs}"
+
+    INIT = "window.ipyvizzu = new window.IpyVizzu(element, '{chart_id}', '{vizzu}', '{div_width}', '{div_height}');"  # pylint: disable=line-too-long
 
     ANIMATE = "window.ipyvizzu.animate(element, '{chart_id}', '{display_target}', {scroll}, {chart_target}, {chart_anim_opts});"  # pylint: disable=line-too-long
     STORED = "window.ipyvizzu.stored(element, '{id}')"
